@@ -1,10 +1,10 @@
 ;;; olivetti.el --- Minor mode for a nice writing environment -*- lexical-binding: t; -*-
 
-;; Copyright (c) 2014-2021  Paul W. Rankin
+;; Copyright (c) 2014-2023  Paul W. Rankin
 
-;; Author: Paul W. Rankin <pwr@bydasein.com>
+;; Author: Paul W. Rankin <hello@paulwrankin.com>
 ;; Keywords: wp, text
-;; Version: 2.0.4
+;; Version: 2.0.5
 ;; Package-Requires: ((emacs "24.4"))
 ;; URL: https://github.com/rnkn/olivetti
 
@@ -98,8 +98,8 @@
 ;; Bugs and Feature Requests
 ;; -------------------------
 
-;; Send me an email (address in the package header). For bugs, please
-;; ensure you can reproduce with:
+;; Use GitHub issues or send me an email (address in the package header).
+;; For bugs, please ensure you can reproduce with:
 
 ;;     $ emacs -Q -l olivetti.el
 
@@ -130,7 +130,7 @@
 (require 'fringe)
 
 (defgroup olivetti ()
-  "Minor mode for a nice writing environment"
+  "Minor mode for a nice writing environment."
   :prefix "olivetti-"
   :group 'text)
 
@@ -148,13 +148,11 @@
 
 (defvar-local olivetti--split-window-preferred-function
   nil
-  "Value of `split-window-preferred-function' when when
-  `olivetti-mode' is enabled.")
+  "Value of `split-window-preferred-function' at initialization.")
 
 (defvar-local olivetti--face-remap
   nil
-  "Saved cookie from `face-remap-add-relative' when
-`olivetti-mode' is enabled.")
+  "Saved cookie from `face-remap-add-relative' at initialization.")
 
 
 ;;; Options ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -238,7 +236,7 @@ will fall back to margins on console."
 (defcustom olivetti-margin-width
   10
   "Width in columns of margin between text body and fringes.
-Only has any effect when `olivetti-style' is set to 'fancy."
+Only has any effect when `olivetti-style' is set to `fancy'."
   :type '(choice (const :tag "None" nil)
                  (integer :tag "Columns" 10))
   :safe 'integerp
@@ -292,6 +290,13 @@ if it is an integer, and otherwise return WIDTH."
   "Call `olivetti-reset-window' on all windows."
   (walk-windows #'olivetti-reset-window nil t))
 
+;; FIXME: these split-window functions seem to be ignored by
+;; `window-toggle-side-windows'
+;; WORKAROUND:
+;; (with-eval-after-load 'olivetti
+;;   (advice-add 'window-toggle-side-windows
+;;               :before 'olivetti-reset-all-windows))
+
 (defun olivetti-split-window (&optional window size side pixelwise)
   "Call `split-window' after resetting WINDOW.
 Pass SIZE, SIDE and PIXELWISE unchanged."
@@ -420,17 +425,21 @@ If prefixed with ARG, incrementally increase."
     (define-key map [left-fringe mouse-1] #'mouse-set-point)
     (define-key map [right-fringe mouse-1] #'mouse-set-point)
     ;; This code is taken from https://github.com/joostkremers/visual-fill-column
-    (when (bound-and-true-p mouse-wheel-mode)
-      (define-key map (vector 'left-margin mouse-wheel-down-event) 'mwheel-scroll)
-      (define-key map (vector 'left-margin mouse-wheel-up-event) 'mwheel-scroll)
-      (define-key map (vector 'right-margin mouse-wheel-down-event) 'mwheel-scroll)
-      (define-key map (vector 'right-margin mouse-wheel-up-event) 'mwheel-scroll))
+    (when (and (bound-and-true-p mouse-wheel-mode)
+               (boundp 'mouse-wheel-down-event)
+               (boundp 'mouse-wheel-up-event))
+      (define-key map (vector 'left-margin 'mouse-wheel-down-event) 'mwheel-scroll)
+      (define-key map (vector 'left-margin 'mouse-wheel-up-event) 'mwheel-scroll)
+      (define-key map (vector 'right-margin 'mouse-wheel-down-event) 'mwheel-scroll)
+      (define-key map (vector 'right-margin 'mouse-wheel-up-event) 'mwheel-scroll))
     map)
   "Mode map for `olivetti-mode'.")
 
 
 ;;; Mode Definition ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+(require 'face-remap)
+
 ;;;###autoload
 (define-minor-mode olivetti-mode
   "Olivetti provides a nice writing environment.
